==> at_location_flutter-0.0.3.tar.gz: lib/map_content/flutter_map_marker_cluster/src/node/marker_cluster_node.dart <==
import 'package:flutter/material.dart';
import 'package:at_location_flutter/map_content/flutter_map/flutter_map.dart';
import 'package:at_location_flutter/map_content/flutter_map/src/map/map.dart';
import 'package:at_location_flutter/map_content/flutter_map_marker_cluster/src/node/marker_node.dart';
import 'package:latlong/latlong.dart';

class MarkerClusterNode {
  final int zoom;
  final MapState map;
  final List<dynamic> children;
  LatLngBounds bounds;
  MarkerClusterNode parent;
  int addCount;
  int removeCount;

  List<MarkerNode> get markers {
    List<MarkerNode> markers = [];

    markers.addAll(children.whereType<MarkerNode>());

    children.forEach((child) {
      if (child is MarkerClusterNode) {
        markers.addAll(child.markers);
      }
    });
    return markers;
  }

  MarkerClusterNode({
    @required this.zoom,
    @required this.map,
  })  : bounds = LatLngBounds(),
        children = [],
        parent = null;

  LatLng get point {
    var swPoint = map.project(bounds.southWest);
    var nePoint = map.project(bounds.northEast);
    return map.unproject((swPoint + nePoint) / 2);
  }

  addChild(dynamic child) {
    assert(child is MarkerNode || child is MarkerClusterNode);
    children.add(child);
    child.parent = this;
    bounds.extend(child.point);
  }

  removeChild(dynamic child) {
    children.remove(child);
    recalculateBounds();
  }

  recalculateBounds() {
    bounds = LatLngBounds();

    markers.forEach((marker) {
      bounds.extend(marker.point);
    });

    children.forEach((child) {
      if (child is MarkerClusterNode) {
        child.recalculateBounds();
      }
    });
  }

  recursively(
      int zoomLevel, int disableClusteringAtZoom, Function(dynamic) fn) {
    if (zoom == zoomLevel && zoomLevel <= disableClusteringAtZoom) {
      fn(this);
      return;
    }

    children.forEach((child) {
      if (child is MarkerNode) {
        fn(child);
      }
      if (child is MarkerClusterNode) {
        child.recursively(zoomLevel, disableClusteringAtZoom, fn);
      }
    });
  }
}

==> at_location_flutter-1.0.3.tar.gz: lib/map_content/flutter_map_marker_cluster/src/node/marker_cluster_node.dart <==
import 'package:flutter/material.dart';
import 'package:at_location_flutter/map_content/flutter_map/flutter_map.dart';
import 'package:at_location_flutter/map_content/flutter_map/src/map/map.dart';
import 'package:at_location_flutter/map_content/flutter_map_marker_cluster/src/node/marker_node.dart';
import 'package:latlong/latlong.dart';

class MarkerClusterNode {
  final int zoom;
  final MapState map;
  final List<dynamic> children;
  LatLngBounds bounds;
  MarkerClusterNode parent;
  int addCount;
  int removeCount;

  List<MarkerNode> get markers {
    var markers = <MarkerNode>[];

    markers.addAll(children.whereType<MarkerNode>());

    children.forEach((child) {
      if (child is MarkerClusterNode) {
        markers.addAll(child.markers);
      }
    });
    return markers;
  }

  MarkerClusterNode({
    @required this.zoom,
    @required this.map,
  })  : bounds = LatLngBounds(),
        children = [],
        parent = null;

  LatLng get point {
    var swPoint = map.project(bounds.southWest);
    var nePoint = map.project(bounds.northEast);
    return map.unproject((swPoint + nePoint) / 2);
  }

  void addChild(dynamic child) {
    assert(child is MarkerNode || child is MarkerClusterNode);
    children.add(child);
    child.parent = this;
    bounds.extend(child.point);
  }

  void removeChild(dynamic child) {
    children.remove(child);
    recalculateBounds();
  }

  void recalculateBounds() {
    bounds = LatLngBounds();

    markers.forEach((marker) {
      bounds.extend(marker.point);
    });

    children.forEach((child) {
      if (child is MarkerClusterNode) {
        child.recalculateBounds();
      }
    });
  }

  void recursively(
      int zoomLevel, int disableClusteringAtZoom, Function(dynamic) fn) {
    if (zoom == zoomLevel && zoomLevel <= disableClusteringAtZoom) {
      fn(this);
      return;
    }

    children.forEach((child) {
      if (child is MarkerNode) {
        fn(child);
      }
      if (child is MarkerClusterNode) {
        child.recursively(zoomLevel, disableClusteringAtZoom, fn);
      }
    });
  }
}
